
import { Code } from "../../../components/Code";
import Collapsible from "../../../components/Collapsible";
import { WikiSelector } from "../../../components/Filter";
export function Troubleshooting(){
  
  return(
    <div>
      Please select what you want to troubleshoot for. 
      <WikiSelector></WikiSelector>
      <div id="nono" className="noshow">
        This combination returns no instances. 
      </div>
       <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-1" title="Argument of type X is not assignable to parameter of type Y. ">
        <h6>Example</h6>
        <h6>Solutions</h6>
       
        </Collapsible>
      </div>
      <div className="filterable all react type"> 
        <Collapsible id="wiki-trouble-2" title="Type X is not assignable to type Y.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all css"> 
        <Collapsible id="wiki-trouble-3" title="I added css styles but they do not show">
        <h6>Example</h6>
        <p>The color is not showing on hover.</p>
        <Code>.nav-link:hover &#123;
          color: var(--darkpurple);
          background-color: var(--yellow) !important;
          border-radius: 3px;
          &#125;</Code>
        <h6>Solution</h6>
        <p>Styles not showing is often a case of a different style overriding your style. Some styles are pre defined by bootstrap or other packages you may use. </p>
        <p> If an external package is overriding your style, you need to add the <b>!important</b> tag to your style. </p>
        <p> If one of your own styles is overriding the new style, you can change your old style or define a new, more specific style case. E.g. by using a more specific css path. But you may still need to add the <b>!important</b> tag. </p>
        <Code> .nav-link:hover &#123;
          color: var(--darkpurple) <b>!important</b>;
          background-color: var(--yellow) !important;
          border-radius: 3px;
          &#125;
          </Code>
        </Collapsible>
      </div>
      <div className="filterable all  react type property">
        <Collapsible id="wiki-trouble-4" title="Property x is missing in type y but required in type z.">
        <h6>Example</h6>
        <p className="problem-error"> Argument of type '&#123; [x: string]: any; &#125;' is not assignable to parameter of type '&#123; classNames: string[]; &#125;'.
        Property 'classNames' is missing in type '&#123; [x: string]: any; &#125;' but required in type '&#123; classNames: string[]; &#125;'.</p>
        <p> for </p>
        <Code>className=&#123;joinClassNames(&#123;[&#39;text-event&#39;, className]&#125;)&#125; </Code>
        <h6>Solutions</h6>
        <p>In this example, the problem was that the property "classNames" was not explicitly named.</p>
        <p>Changing it to </p>
          <Code>className=&#123;joinClassNames(&#123;<b>classNames:</b>[&#39;text-event &#39;, className]&#125;)&#125;</Code>
        </Collapsible>
      </div>
      <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-5" title="Property x does not exist on type Y.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-6" title="Type X is missing the following properties from type Y: a, b, c">
        <h6>Example</h6>
        <p className="problem-error">
        Type '&#123; date: string; text: string; &#125;' is missing the following properties from type 'TextEventProps': marker, card
        </p>
        <p>In reference of the interface TextEventProps:</p>
        <Code>
        <p>interface TextEventProps &#123; </p>
        <p>date: string; </p>
        <p>text: string; </p>
        <p>marker: React.ReactNode; </p>
        <p>id: string; </p>
        <p>card: Function; </p>
        &#125;
        </Code>
        <p>For the code:</p>
        <Code>
          <p> &lt;TextEvent </p>
          <p> id="05"</p>
          <p> date="14-06-2024"</p>
          <p> text="Test test"</p>
          <p> /&gt;</p>
        </Code>
        <h6>Solutions</h6>
        <p>One solution could be getting rid of the properties you do not need everywhere and create new property interfaces for all cases.</p>
        <p>If you want to stick to more general Interfaces, you can make properties optional:</p>
        <Code>
        <p>interface TextEventProps &#123; </p>
        <p>date: string; </p>
        <p>text: string; </p>
        <p>marker?: React.ReactNode; </p>
        <p>id: string; </p>
        <p>card?: Function; </p>
        &#125;
        </Code>
        <p>Remember that this can lead to different return cases for your functions.</p>
        </Collapsible>
      </div>
      <div className="filterable all react type">
        <Collapsible id="wiki-trouble-7" title="Type 'x | undefined' is not assignable to type 'x'.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all pipeline">
        <Collapsible id="wiki-trouble-8" title="The pipeline passed but the Wiki is not visible under the url">
        <p>This error could be a result of a wrong base url in the vite.config.js file.</p>
        <p>E.g. if you switched from plain HTML to the react framework. </p>
        <h6>Example</h6>
        <Code>
          <p>return defineConfig(&#123;</p>
          <p>base: `/`,</p>
          <p>...</p>
        </Code>
        <h6>Solution</h6>
        <p>Change the base url to reflect the correct team url.</p>
        <Code>
          <p>return defineConfig(&#123;</p>
          <p>base: `/$&#123;stringToSlug(env.VITE_TEAM_NAME)&#125;/`,</p>
          <p>...</p>
        </Code>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-9" title="NS_ERROR_CORRUPTED_CONTENT error in console">
        <p> &rarr; See also "The pipeline passed but the Wiki is not visible under the url" as these errors can be connected.</p>
        <p> This error for css and js files can be the result of wrong <b>rollupOptions</b> in for the build, to be specific wrong <b>output</b> and <b>assetFileNames</b> options and possibly wrong/empty <b>css</b> options in your vite.config.js. </p>
        <h6>Example</h6>
        <p>In our case, we had the following code on our vite.config.js</p>
        <Code>
        <p>build: &#123; </p>
      <p>outDir: "dist",</p>
      <p>rollupOptions: &#123;</p>
        <p>output: &#123;</p>
          <p> assetFileNames: `assets/[ext]/[name]-[hash].[ext]`</p>
        <p>&#125; &#125; &#125; , </p>
        </Code>
        <p> Our <b>css</b> options were empty, which could also have played a factor for the css files.</p>
        <Code>
        <p>css: &#123;</p>
      <p>preprocessorOptions: &#123;</p>
        <p>css: &#123;</p>
          <p>  //javascriptEnabled: true, // Enable JavaScript in CSS (useful for certain CSS preprocessor plugins)</p>
       <p> &#125; &#125; &#125;,</p>  
        </Code>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-10" title="Blocked due to MIME type (“text/html”) mismatch (X-Content-Type-Options: nosniff) (Firefox)">
        <p> &rarr; See also "Refused to apply style from &lt;&lt;css file&gt;&gt; because its MIME type ('text/html') is not a supported stylesheet MIME type, strict MIME checking is enabled (Edge)"</p>
        <p>This error could </p>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-11" title="Refused to apply style from <<css file>> because its MIME type ('text/html') is not a supported stylesheet MIME type, strict MIME checking is enabled (Edge)">
        <p> &rarr; See also "Blocked due to MIME type (“text/html”) mismatch (X-Content-Type-Options: nosniff) (Firefox)"</p>
        <p>This error could </p>
        </Collapsible>
      </div>
      <div className="filterable all react type">
        <Collapsible id="wiki-trouble-12" title="Type 'undefined' cannot be used as an index type">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all react overload">
        <Collapsible id="wiki-trouble-13" title="No overload matches this call.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div> 
      <div className="filterable all react module">
        <Collapsible id="wiki-trouble-14" title="Module Z has already exported a member named A. Consider explicitly re-exporting to resolve the ambiguity.">
        <h6>Example</h6>
        index.tsx: 
        <p className="problem-error"> Module "./Bfh.tsx" has already exported a member named 'LabTabs'. Consider explicitly re-exporting to resolve the ambiguity.</p>
        <h6>Solutions</h6>
        Simply rename the function in one of the modules or consider making it a component if you plan on using it frequently.  
        </Collapsible>
      </div>
      <div className="filterable all pipeline">
        <Collapsible id="wiki-trouble-15" title="error TS6133: 'event' is declared but its value is never read.">
          <h6>Example</h6>
          HorizontalTimeline.tsx: 
          <div className="terminal-box">
            $ yarn build
            <p>yarn run v1.22.19</p>
            <p>$ tsc && vite build</p>
            <p className="terminal-error">src/components/HorizontalTimeline.tsx(67,23): error TS6133: 'event' is declared but its value is never read.
            error Command failed with exit code 2.</p>
            <p>info Visit https://yarnpkg.com/en/docs/cli/run for documentation about this command.</p>
            </div>
          <p>in</p>
          <Code>
          const openPop =  (event : React.MouseEvent&lt;HTMLButtonElement, MouseEvent&gt;) =&gt; {}
          </Code>
          <h6>Solutions</h6>
          <p>Change to: </p>
          <Code>
          const openPop =  (_event : React.MouseEvent&lt;HTMLButtonElement, MouseEvent&gt;) =&gt; {}
          </Code>
        </Collapsible>
      </div>
    </div>
  )
} 
